@@ -2,9 +2,9 @@ import json
 from pathlib import Path
 from threading import Lock
 
+from je_auto_control.utils.exception.exception_tags import cant_find_json_error
+from je_auto_control.utils.exception.exception_tags import cant_save_json_error
 from je_auto_control.utils.exception.exceptions import AutoControlJsonActionException
-from je_auto_control.utils.exception.exception_tag import cant_save_json_error
-from je_auto_control.utils.exception.exception_tag import cant_find_json_error
 
 _lock = Lock()
 
@@ -40,4 +40,3 @@ def write_action_json(json_save_path: str, action_json: list) -> None:
         raise AutoControlJsonActionException(cant_save_json_error)
     finally:
         _lock.release()
-
